# Invoice Management

A comprehensive Drupal module for managing invoices with modern design, automatic numbering, and configurable branding.

## Features

### 🧾 Invoice Management
- **Automatic Invoice Numbering**: Configurable prefix with format `PREFIX-YYYYMM-UNIQUECODE` (e.g., `INV-202501-001`)
- **Sequential Numbering**: Auto-incremental numbering per month to avoid duplicates
- **Non-editable Invoice Numbers**: Prevents manual editing of generated invoice numbers

### 🎨 Modern Design & Branding
- **Configurable Colors**: Customize primary, secondary, and accent colors for brand consistency
- **Professional Templates**: Modern, responsive invoice templates with gradient headers
- **Logo Support**: Upload and display company logos on invoices
- **Print-Optimized**: Clean, professional appearance when printed

### ⚙️ Flexible Configuration
- **Company Information**: Configure seller name, address, and contact details
- **Terms & Conditions**: Customizable terms and conditions text
- **Bank Details**: Payment information and bank account details
- **Currency Support**: Built-in support for GBP, USD, EUR, AED, and INR with proper symbols
- **Footer Text**: Customizable footer messaging

### 📋 Invoice Features
- **Line Items**: Support for paragraph-based invoice items with taxonomy term names and amounts
- **Client Integration**: Link invoices to client nodes with automatic data population
- **Totals Calculation**: Automatic calculation and display of item totals
- **Status Management**: Track invoice status (paid, pending, overdue, draft)
- **Date Management**: Invoice date and due date tracking

### 🔗 Integration Ready
- **Entity Print Compatible**: Ready for PDF generation (requires entity_print module)
- **Paragraphs Integration**: Uses paragraphs for flexible invoice item management
- **Field Group Support**: Organized form layouts with field grouping
- **Tagify Integration**: Enhanced field widgets for better UX

## Requirements

- **Drupal**: ^9.0 || ^10.0 || ^11.0
- **Paragraphs**: ^1.0 (for invoice items)
- **Field Group**: ^3.0 || ^4.0 (for organized forms)
- **Tagify**: ^1.0 (for enhanced field widgets)

### Optional Requirements
- **Entity Print**: ^2.0 (for PDF generation)

## Installation

### Via Composer (Recommended)
```bash
composer require drupal/invoicemgmt
drush en invoicemgmt
```

### Manual Installation
1. Download and extract the module to `/modules/custom/invoicemgmt`
2. Enable the module: `drush en invoicemgmt`
3. Install dependencies if not already present

## Configuration

### 1. Module Settings
Navigate to **Administration > Configuration > System > Invoice Management** (`/admin/config/invoicemgmt/settings`)

Configure:
- **Logo**: Upload company logo (PNG, JPG, JPEG, GIF - max 2MB)
- **Company Information**: Seller name and address
- **Terms & Conditions**: Legal terms and conditions text
- **Bank Details**: Payment and banking information
- **Currency**: Select default currency (GBP, USD, EUR, AED, INR)
- **Invoice Prefix**: Customize invoice number prefix (default: "INV")
- **Footer Text**: Custom footer message
- **Brand Colors**: 
  - Primary Color: Header gradient start color
  - Secondary Color: Header gradient end color  
  - Accent Color: Highlights and borders

### 2. Content Types Setup

#### Invoice Content Type
Ensure your invoice content type includes these fields:
- `field_invoice_number` (Text) - Auto-populated, non-editable
- `field_client` (Entity Reference to Client nodes)
- `field_items` (Paragraphs reference to invoice_item paragraphs)
- `field_invoice_date` (Date)
- `field_due_date` (Date)
- `field_invoice_status` (List/Select)
- `field_subtotal`, `field_tax_amount`, `field_discount`, `field_total_amount` (Decimal)
- `field_invoice_notes` (Text area)

#### Client Content Type
Your client content type should include:
- `title` (Node title for client name)
- `field_client_email` (Email)
- `field_client_phone` (Telephone)
- `field_client_address` (Text area)

#### Invoice Item Paragraph Type
Create a paragraph type `invoice_item` with:
- `field_item_name` (Entity Reference to Taxonomy Terms)
- `field_amount` (Decimal)

## Usage

### Creating Invoices
1. Navigate to **Content > Add content > Invoice**
2. Fill in invoice details (invoice number auto-generates)
3. Select or add a client using the "Add Client" quick link
4. Add invoice items using the paragraph interface
5. Save the invoice

### Invoice Display
- **Web View**: Modern, responsive design with configurable colors
- **Print View**: Optimized for printing with clean layout
- **PDF Export**: Compatible with Entity Print module for PDF generation

### Managing Settings
- Update company branding through the configuration form
- Customize colors to match your brand identity
- Modify terms, conditions, and payment information as needed

## Theming

### Template Files
- `templates/node--invoice--full.html.twig` - Main invoice template
- `templates/node--invoice--pdf.html.twig` - PDF-specific template
- `css/invoice-styles.css` - Invoice styling

### Customization
The module uses CSS custom properties for easy color customization:
```css
:root {
  --primary-color: /* Configurable primary color */
  --secondary-color: /* Configurable secondary color */
  --accent-color: /* Configurable accent color */
}
```

### Template Variables
Available in invoice templates:
- `invoice_data` - Configuration data (colors, company info, etc.)
- `client_data` - Client node information
- `invoice_items` - Processed invoice line items
- `invoice_items_total` - Calculated total of all items

## Permissions

The module defines these permissions:
- **Administer Invoice Management settings**: Access to configuration form

## Development

### Module Structure
```
invoicemgmt/
├── config/
│   └── schema/
│       └── invoicemgmt.schema.yml
├── css/
│   └── invoice-styles.css
├── src/
│   ├── Form/
│   │   └── InvoiceMgmtSettingsForm.php
│   └── InvoiceNumberGenerator.php
├── templates/
│   ├── node--invoice--full.html.twig
│   └── node--invoice--pdf.html.twig
├── composer.json
├── invoicemgmt.info.yml
├── invoicemgmt.libraries.yml
├── invoicemgmt.links.menu.yml
├── invoicemgmt.module
├── invoicemgmt.permissions.yml
├── invoicemgmt.routing.yml
└── invoicemgmt.services.yml
```

### Services
- `invoicemgmt.invoice_number_generator` - Handles unique invoice number generation

### Hooks Implemented
- `hook_entity_presave()` - Auto-generates invoice numbers
- `hook_form_alter()` - Makes invoice number non-editable and adds client quick-add link
- `hook_theme()` - Registers invoice templates
- `template_preprocess_node()` - Processes invoice data for templates

## Contributing

We welcome contributions! Please see the [Contributing Guide](#contributing-to-drupalorg) for submitting this module to Drupal.org.

## Support

For bug reports and feature requests, please use the issue queue on Drupal.org.

## License

GPL-2.0+

---

## Credits

Developed with ❤️ for the Drupal community.
